ignite.contrib.engines
======================

Contribution module of engines and helper tools:

ignite.contrib.engines.tbptt

.. currentmodule:: ignite.contrib.engines.tbptt

.. autosummary::
    :nosignatures:
    :autolist:

ignite.contrib.engines.common

.. currentmodule:: ignite.contrib.engines.common

.. autosummary::
    :nosignatures:
    :autolist:

Truncated Backpropagation Through Time
---------------------------------------

.. automodule:: ignite.contrib.engines.tbptt
   :members:

Helper methods to setup trainer/evaluator
-----------------------------------------

.. automodule:: ignite.contrib.engines.common
   :members:
